@@ -25,10 +25,8 @@ Usage::
     list_types_paginator: ListTypesPaginator = client.get_paginator("list_types")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from __future__ import annotations
-
 import sys
-from typing import Generator
+from typing import Generator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_appsync.type_defs import (
     ListApiKeysResponseTypeDef,
@@ -60,85 +58,85 @@ __all__ = (
 
 class ListApiKeysPaginator(Boto3Paginator):
     """
-    [Paginator.ListApiKeys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)
+    [Paginator.ListApiKeys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)
     """
 
     def paginate(
         self, apiId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListApiKeysResponseTypeDef, None, None]:
         """
-        [ListApiKeys.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListApiKeys.paginate)
+        [ListApiKeys.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListApiKeys.paginate)
         """
 
 
 class ListDataSourcesPaginator(Boto3Paginator):
     """
-    [Paginator.ListDataSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListDataSources)
+    [Paginator.ListDataSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListDataSources)
     """
 
     def paginate(
         self, apiId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListDataSourcesResponseTypeDef, None, None]:
         """
-        [ListDataSources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListDataSources.paginate)
+        [ListDataSources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListDataSources.paginate)
         """
 
 
 class ListFunctionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListFunctions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListFunctions)
+    [Paginator.ListFunctions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListFunctions)
     """
 
     def paginate(
         self, apiId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListFunctionsResponseTypeDef, None, None]:
         """
-        [ListFunctions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListFunctions.paginate)
+        [ListFunctions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListFunctions.paginate)
         """
 
 
 class ListGraphqlApisPaginator(Boto3Paginator):
     """
-    [Paginator.ListGraphqlApis documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)
+    [Paginator.ListGraphqlApis documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListGraphqlApisResponseTypeDef, None, None]:
         """
-        [ListGraphqlApis.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis.paginate)
+        [ListGraphqlApis.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis.paginate)
         """
 
 
 class ListResolversPaginator(Boto3Paginator):
     """
-    [Paginator.ListResolvers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListResolvers)
+    [Paginator.ListResolvers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListResolvers)
     """
 
     def paginate(
         self, apiId: str, typeName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListResolversResponseTypeDef, None, None]:
         """
-        [ListResolvers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListResolvers.paginate)
+        [ListResolvers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListResolvers.paginate)
         """
 
 
 class ListResolversByFunctionPaginator(Boto3Paginator):
     """
-    [Paginator.ListResolversByFunction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)
+    [Paginator.ListResolversByFunction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)
     """
 
     def paginate(
         self, apiId: str, functionId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListResolversByFunctionResponseTypeDef, None, None]:
         """
-        [ListResolversByFunction.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction.paginate)
+        [ListResolversByFunction.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction.paginate)
         """
 
 
 class ListTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListTypes)
+    [Paginator.ListTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListTypes)
     """
 
     def paginate(
@@ -148,5 +146,5 @@ class ListTypesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Generator[ListTypesResponseTypeDef, None, None]:
         """
-        [ListTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/appsync.html#AppSync.Paginator.ListTypes.paginate)
+        [ListTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/appsync.html#AppSync.Paginator.ListTypes.paginate)
         """
